Stan Math Library: stan/math/rev/scal/fun/boost_isnormal.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

boost_isnormal.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_BOOST_ISNORMAL_HPP
2 #define STAN_MATH_REV_SCAL_FUN_BOOST_ISNORMAL_HPP
3
4 #include <boost/math/special_functions/fpclassify.hpp>
5 #include <stan/math/rev/core.hpp>
6
7 namespace boost {
8
9 namespace math {
10
20 template <>
21 inline
22 bool isnormal(const stan::math::var& v) {
23 return (boost::math::isnormal)(v.val());
24 }
25
26 }
27 }
28 #endif
29
core.hpp
boost
Reimplementing boost functionality.
Definition: boost_fpclassify.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
boost::math::isnormal
bool isnormal(const stan::math::var &v)
Checks if the given number is normal.
Definition: boost_isnormal.hpp:22
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.